@@ -42,7 +42,7 @@ setMethodS3("findAtomicAberrations", "PairedPSCBS", function(this, H=1, alpha=0.
   verbose && enter(verbose, "Setting up extractSignals()");
   if (is.element(flavor, c("mean(tcn)", "t(tcn)"))) {
     extractSignals <- function(..., na.rm=TRUE) {
-      C <- extractLocusLevelTCN(...);  
+      C <- extractLocusLevelTCN(...);
       # Drop missing values?
       if (na.rm) {
         C <- C[is.finite(C)];
@@ -51,7 +51,7 @@ setMethodS3("findAtomicAberrations", "PairedPSCBS", function(this, H=1, alpha=0.
     } # extractSignals()
   } else if (is.element(flavor, c("mean(c1,c2)", "t(c1)|t(c2)", "chisq(c1,c2)"))) {
     extractSignals <- function(..., na.rm=TRUE) {
-      data <- extractLocusLevelC1C2(...);  
+      data <- extractLocusLevelC1C2(...);
       # Drop missing values?
       if (na.rm) {
         ok <- is.finite(data$C1) & is.finite(data$C2);
@@ -99,8 +99,8 @@ setMethodS3("findAtomicAberrations", "PairedPSCBS", function(this, H=1, alpha=0.
     # The two flanking regions
     idxL <- rr-1;
     idxR <- rr+H;
-    fitL <- extractByRegion(this, region=idxL);
-    fitR <- extractByRegion(this, region=idxR);
+    fitL <- extractRegion(this, region=idxL);
+    fitR <- extractRegion(this, region=idxR);
 
     # Extract their data
     verbose && enter(verbose, "Extracting signals");
@@ -154,12 +154,12 @@ setMethodS3("findAtomicAberrations", "PairedPSCBS", function(this, H=1, alpha=0.
     if (!is.null(fit)) {
       verbose && cat(verbose, "fit:");
       verbose && str(verbose, fit);
-      verbose && printf(verbose, "t=%.3f (p=%g), (alpha=%g) (L==R)=%s\n", 
+      verbose && printf(verbose, "t=%.3f (p=%g), (alpha=%g) (L==R)=%s\n",
                          fit$statistic, fit$p.value, alpha, isEqual);
     }
     rm(dataL, dataR, fit); # Not needed anymore
 
-    # If the two flanking regions are equal, then we have 
+    # If the two flanking regions are equal, then we have
     # found an atomic region.
     # Also, in case either of the regions compared contains
     # no data points, which may happen with (C1,C2) when
@@ -184,7 +184,7 @@ setMethodS3("findAtomicAberrations", "PairedPSCBS", function(this, H=1, alpha=0.
 #    stop        = stop[atomicRegions+(H-1L)]
   );
 
-  # Atomic islands = atomic regions that are not next 
+  # Atomic islands = atomic regions that are not next
   # to another atomic region
   dups <- which(diff(atomicRegions) == H);
   if (length(dups) > 0) {
